==> phpunit_12.4.0.orig.tar.xz: phpunit-12.4.0/tests/unit/Event/Value/Telemetry/InfoTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Event\Telemetry;

use PHPUnit\Framework\Attributes\CoversClass;
use PHPUnit\Framework\Attributes\Small;
use PHPUnit\Framework\TestCase;

#[CoversClass(Info::class)]
#[Small]
final class InfoTest extends TestCase
{
    public function testHasTime(): void
    {
        $this->assertInstanceOf(HRTime::class, $this->info()->time());
    }

    public function testHasMemoryUsage(): void
    {
        $this->assertInstanceOf(MemoryUsage::class, $this->info()->memoryUsage());
    }

    public function testHasPeakMemoryUsage(): void
    {
        $this->assertInstanceOf(MemoryUsage::class, $this->info()->peakMemoryUsage());
    }

    public function testHasDurationSinceStart(): void
    {
        $this->assertSame(0, $this->info()->durationSinceStart()->nanoseconds());
    }

    public function testHasDurationSincePrevious(): void
    {
        $this->assertSame(0, $this->info()->durationSincePrevious()->nanoseconds());
    }

    public function testHasMemoryUsageSinceStart(): void
    {
        $this->assertSame(0, $this->info()->memoryUsageSinceStart()->bytes());
    }

    public function testHasMemoryUsageSincePrevious(): void
    {
        $this->assertSame(0, $this->info()->memoryUsageSincePrevious()->bytes());
    }

    public function testHasGarbageCollectorStatus(): void
    {
        $this->assertInstanceOf(GarbageCollectorStatus::class, $this->info()->garbageCollectorStatus());
    }

    public function testCanBeFormattedAsString(): void
    {
        $this->assertStringMatchesFormat(
            '[00:00:00.000000000 / 00:00:00.000000000] [%d bytes]',
            $this->info()->asString(),
        );
    }

    private function info(): Info
    {
        $current = $this->telemetrySystem()->snapshot();

        return new Info(
            $current,
            $current->time()->duration($current->time()),
            $current->memoryUsage()->diff($current->memoryUsage()),
            $current->time()->duration($current->time()),
            $current->memoryUsage()->diff($current->memoryUsage()),
        );
    }

    private function telemetrySystem(): System
    {
        return new System(
            new SystemStopWatch,
            new SystemMemoryMeter,
            new SystemGarbageCollectorStatusProvider,
        );
    }
}

==> phpunit_13.0.2.orig.tar.xz: phpunit-13.0.2/tests/unit/Event/Value/Telemetry/InfoTest.php <==
<?php declare(strict_types=1);
/*
 * This file is part of PHPUnit.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace PHPUnit\Event\Telemetry;

use PHPUnit\Framework\Attributes\CoversClass;
use PHPUnit\Framework\Attributes\Group;
use PHPUnit\Framework\Attributes\Small;
use PHPUnit\Framework\TestCase;

#[CoversClass(Info::class)]
#[Small]
#[Group('event-system')]
#[Group('event-system/value-objects')]
final class InfoTest extends TestCase
{
    public function testHasTime(): void
    {
        $this->assertInstanceOf(HRTime::class, $this->info()->time());
    }

    public function testHasMemoryUsage(): void
    {
        $this->assertInstanceOf(MemoryUsage::class, $this->info()->memoryUsage());
    }

    public function testHasPeakMemoryUsage(): void
    {
        $this->assertInstanceOf(MemoryUsage::class, $this->info()->peakMemoryUsage());
    }

    public function testHasDurationSinceStart(): void
    {
        $this->assertSame(0, $this->info()->durationSinceStart()->nanoseconds());
    }

    public function testHasDurationSincePrevious(): void
    {
        $this->assertSame(0, $this->info()->durationSincePrevious()->nanoseconds());
    }

    public function testHasMemoryUsageSinceStart(): void
    {
        $this->assertSame(0, $this->info()->memoryUsageSinceStart()->bytes());
    }

    public function testHasMemoryUsageSincePrevious(): void
    {
        $this->assertSame(0, $this->info()->memoryUsageSincePrevious()->bytes());
    }

    public function testHasGarbageCollectorStatus(): void
    {
        $this->assertInstanceOf(GarbageCollectorStatus::class, $this->info()->garbageCollectorStatus());
    }

    public function testCanBeFormattedAsString(): void
    {
        $this->assertStringMatchesFormat(
            '[00:00:00.000000000 / 00:00:00.000000000] [%d bytes]',
            $this->info()->asString(),
        );
    }

    private function info(): Info
    {
        $current = $this->telemetrySystem()->snapshot();

        return new Info(
            $current,
            $current->time()->duration($current->time()),
            $current->memoryUsage()->diff($current->memoryUsage()),
            $current->time()->duration($current->time()),
            $current->memoryUsage()->diff($current->memoryUsage()),
        );
    }

    private function telemetrySystem(): System
    {
        return new System(
            new SystemStopWatch,
            new SystemMemoryMeter,
            new SystemGarbageCollectorStatusProvider,
        );
    }
}
